<template>
  <AdminLayout>
    <DashboardHeader>
      <DashboardTitle>{{ $t("app.admin.settings.seo.title") }}</DashboardTitle>
    </DashboardHeader>
    <SettingsBody>
      <template v-if="seoSettingsFetch.hasErrors">
        <ErrorState />
      </template>
      <template v-else>
        <FormGroup
          :is-loading="seoSettingsFetch.isFetching"
          @submit="submit"
        >
          <AlertError v-if="form.errors && form.errors?.unknown">
            {{ form.errors.unknown }}
          </AlertError>
          <FormSection>
            <FormInput
              id="home_title"
              :errors="form.errors.home_title"
            >
              <FormLabel>{{ $t("app.admin.settings.seo.form.home_title") }}</FormLabel>
              <FormText
                v-model="form.values.home_title"
                name="home_title"
                required
                type="text"
              />
            </FormInput>
            <FormInput
              id="title_template"
              :errors="form.errors.title_template"
            >
              <FormLabel>{{ $t("app.admin.settings.seo.form.title_template") }}</FormLabel>
              <FormText
                v-model="form.values.title_template"
                name="title_template"
                required
                type="text"
              />
            </FormInput>
            <FormInput
              id="title_separator"
              :errors="form.errors.title_separator"
            >
              <FormLabel>{{ $t("app.admin.settings.seo.form.title_separator") }}</FormLabel>
              <FormText
                v-model="form.values.title_separator"
                name="title_separator"
                required
                type="text"
              />
            </FormInput>
            <FormInput
              id="description"
              :errors="form.errors.description"
            >
              <FormLabel>{{ $t("app.admin.settings.seo.form.description") }}</FormLabel>
              <FormText
                v-model="form.values.description"
                name="description"
                type="text"
              />
            </FormInput>
            <FormInput
              id="keywords"
              :errors="form.errors.keywords"
            >
              <FormLabel>{{ $t("app.admin.settings.seo.form.keywords") }}</FormLabel>
              <FormText
                v-model="form.values.keywords"
                name="keywords"
                type="text"
              />
            </FormInput>
            <div class="space-y-1">
              <FormLabel>{{ $t("app.admin.settings.seo.preview") }}</FormLabel>
              <div class="mt-1 grid rounded border border-gray-900/10 p-3">
                <div class="h-5 pt-px text-left text-xs not-italic text-gray-900 hover:cursor-pointer">
                  {{ url }}
                </div>
                <div class="h-6 text-left font-medium text-indigo-800 hover:cursor-pointer hover:underline">
                  {{ form.values.home_title ?? url }}
                </div>
                <div class="h-5 truncate text-left text-sm not-italic text-gray-700">
                  {{ form.values.description }}
                </div>
              </div>
            </div>
          </FormSection>
          <div>
            <FormSubmit
              :processing="form.isFetching"
              class="btn btn-black"
            >
              {{ $t("app.admin.settings.submit") }}
            </FormSubmit>
          </div>
        </FormGroup>
      </template>
    </SettingsBody>
  </AdminLayout>
</template>

<script lang="ts" setup>
import DashboardHeader from "@/js/contexts/shared/ui/components/dashboard/DashboardHeader.vue";
import DashboardTitle from "@/js/contexts/shared/ui/components/dashboard/DashboardTitle.vue";
import AdminLayout from "@/js/contexts/admin/shared/ui/layouts/AdminLayout.vue";
import SettingsBody from "@/js/contexts/admin/settings/ui/components/SettingsBody.vue";
import FormSection from "@/js/contexts/form/ui/components/FormSection.vue";
import useForm from "@/js/contexts/shared/composables/useForm";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import useFetch from "@/js/contexts/shared/composables/useFetch";
import FormGroup from "@/js/contexts/form/ui/components/FormGroup.vue";
import ErrorState from "@/js/contexts/shared/ui/components/error/ErrorState.vue";
import useNotification from "@/js/contexts/shared/composables/useNotification";

type Response = { home_title: string; title_template: string; title_separator: string; description: string; keywords: string };

const { t } = useI18n();
const { successNotification } = useNotification();

useHead({
  title: t("app.admin.settings.seo.title"),
});

const seoSettingsFetch = useFetch("/api/admin/settings/seo", { isFetching: true });

const form = useForm({
  home_title: "",
  title_template: "",
  title_separator: "",
  description: "",
  keywords: "",
});

onMounted(() => {
  seoSettingsFetch.get<Response>().then((response) => {
    form.values.home_title = response.data.home_title;
    form.values.title_template = response.data.title_template;
    form.values.title_separator = response.data.title_separator;
    form.values.description = response.data.description;
    form.values.keywords = response.data.keywords;
    form.updatedValues();
  });
});

const url = computed(() => location.host);

const submit = () => {
  form.post("/api/admin/settings/seo", {
    onSuccess: () => successNotification(t("app.admin.settings.success")),
  });
};
</script>
